@@ -17,31 +17,59 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Represent Universal Tracking Data Format (UTDF) data';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db xt/author/optionals } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
 sub build_requires {
     return +{
+	lib		=> 0,
 	'Test::More'	=> 0.88,	# Because of done_testing().
     };
 }
 
+sub configure_requires {
+    return +{
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Astro-UTDF';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
     my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
 	},
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
+	dynamic_config	=> 1,
 	resources	=> {
 	    bugtracker	=> {
-                web	=> 'https://github.com/trwyant/perl-Astro-UTDF/issues',
-                mailto  => 'wyant@cpan.org',
-            },
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-UTDF',
+		# web	=> 'https://github.com/trwyant/perl-Astro-UTDF/issues',
+		mailto  => 'wyant@cpan.org',
+	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
@@ -53,6 +81,20 @@ sub meta_merge {
     };
 }
 
+sub module_name {
+    return 'Astro::UTDF';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
 sub provides {
     -d 'lib'
 	or return;
@@ -74,6 +116,8 @@ sub requires {
 	'POSIX'		=> 0,
 	'Scalar::Util'	=> 0,
 	'Time::Local'	=> 0,
+	bytes		=> 0,
+	constant	=> 0,
 	strict		=> 0,
 	warnings	=> 0,
 	@extra,
@@ -84,6 +128,14 @@ sub requires_perl {
     return 5.006002;
 }
 
+sub script_files {
+    return [
+    ];
+}
+
+sub version_from {
+    return 'lib/Astro/UTDF.pm';
+}
 
 1;
 
@@ -118,6 +170,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -128,6 +193,20 @@ modules required to build the C<Astro::UTDF> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -139,6 +218,10 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -146,10 +229,21 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<no_index> and C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
 
 Any arguments will be appended to the generated array.
 
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -179,11 +273,20 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -192,12 +295,12 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://github.com/trwyant/perl-Astro-UTDF/issues>, or in electronic
-mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-UTDF>,
+L<https://github.com/trwyant/perl-Astro-UTDF/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
